@@ -1,4 +1,4 @@
-/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
+/* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 2; tab-width: 2 -*- */
 
 /*
  *   Gnome Nibbles: Gnome Worm Game
@@ -199,7 +199,7 @@ gint
 gnibbles_move_worms (void)
 {
   gint i, j;
-  gint status = 1, nlives = 1;
+  gint nlives = 1;
   gint *dead;
 
   dead = g_new (gint, properties->numworms);
@@ -233,7 +233,6 @@ gnibbles_move_worms (void)
 
   for (i = 0; i < properties->numworms; i++) {
     dead[i] = !gnibbles_worm_test_move_head (worms[i]);
-    status &= !dead[i];
   }
 
   for (i = 0; i < properties->numworms; i++) {
@@ -270,11 +269,7 @@ gnibbles_move_worms (void)
     }
   }
 
-  if (status & GAMEOVER) {
-    play_sound ("crash");
-    play_sound ("gameover");
-    return GAMEOVER;
-  }
+  g_free (dead);
 
   for (i = 0; i < properties->numworms; i++) {
     if (worms[i]->human && worms[i]->lives <= 0)
@@ -296,7 +291,11 @@ gnibbles_move_worms (void)
   }
    /* Noone died, so the round can continue. */
 
-  g_free (dead);
+  for (i = 0; i < properties->numworms; i++) {
+    /* Verify that worm length is as expected */
+    (void) gnibbles_board_count_worm_segments_for_worm (board, worms[i]);
+  }
+
   return CONTINUE;
 }
 
