@@ -441,7 +441,7 @@ animate_end_game (void)
   for (i = 0; i < properties->numworms; i++) {
     clutter_actor_save_easing_state(worms[i]->actors);
     clutter_actor_set_easing_mode (worms[i]->actors, CLUTTER_EASE_IN_QUAD);
-    clutter_actor_set_easing_duration (worms[i]->actors, 500);
+    clutter_actor_set_easing_duration (worms[i]->actors, GAMEDELAY * 15);
     clutter_actor_set_scale (worms[i]->actors, 0.4, 0.4);
     clutter_actor_set_opacity (worms[i]->actors, 0);
     clutter_actor_restore_easing_state(worms[i]->actors);
@@ -450,7 +450,7 @@ animate_end_game (void)
   for ( i = 0; i < boni->numbonuses; i++) {
     clutter_actor_save_easing_state(boni->bonuses[i]->actor);
     clutter_actor_set_easing_mode (boni->bonuses[i]->actor, CLUTTER_EASE_IN_QUAD);
-    clutter_actor_set_easing_duration (boni->bonuses[i]->actor, 500);
+    clutter_actor_set_easing_duration (boni->bonuses[i]->actor, GAMEDELAY * 15);
     clutter_actor_set_scale (boni->bonuses[i]->actor, 0.4, 0.4);
     clutter_actor_set_pivot_point (boni->bonuses[i]->actor,.5,.5);
     clutter_actor_set_opacity (boni->bonuses[i]->actor, 0);
@@ -460,7 +460,7 @@ animate_end_game (void)
   for ( i = 0; i < warpmanager->numwarps; i++) {
     clutter_actor_save_easing_state(warpmanager->warps[i]->actor);
     clutter_actor_set_easing_mode (warpmanager->warps[i]->actor, CLUTTER_EASE_IN_QUAD);
-    clutter_actor_set_easing_duration (warpmanager->warps[i]->actor, 500);
+    clutter_actor_set_easing_duration (warpmanager->warps[i]->actor, GAMEDELAY * 15);
     clutter_actor_set_scale (warpmanager->warps[i]->actor, 0.4, 0.4);
     clutter_actor_set_pivot_point (warpmanager->warps[i]->actor,.5,.5);
     clutter_actor_set_opacity (warpmanager->warps[i]->actor, 0);
@@ -469,7 +469,7 @@ animate_end_game (void)
 
   clutter_actor_save_easing_state(board->level);
   clutter_actor_set_easing_mode (board->level, CLUTTER_EASE_IN_QUAD);
-  clutter_actor_set_easing_duration (board->level, 700);
+  clutter_actor_set_easing_duration (board->level, GAMEDELAY * 20);
   clutter_actor_set_scale (board->level, 0.4, 0.4);
   clutter_actor_set_pivot_point (board->level,.5,.5);
   clutter_actor_set_opacity (board->level, 0);
